@@ -37,6 +37,7 @@ class GaarfOperator(BaseOperator):
                  reader_client: AbsReader,
                  google_ads_conn_id: str,
                  api_version: str,
+                 optimize_performance: str = "NONE",
                  page_size: int = 10000,
                  **kwargs) -> None:
         super().__init__(**kwargs)
@@ -45,6 +46,7 @@ class GaarfOperator(BaseOperator):
         self.customer_ids = customer_ids
         self.writer_client = writer_client
         self.reader_client = reader_client
+        self.optimize_performance = optimize_performance
         self.google_ads_conn_id = google_ads_conn_id
         self.api_version = api_version
         self.page_size = page_size
@@ -56,7 +58,8 @@ class GaarfOperator(BaseOperator):
                                              self.customer_ids)
         executor = AdsQueryExecutor(client.get_client)
         executor.execute(self.query, self.customer_ids, self.reader_client,
-                         self.writer_client, self.query_params)
+                         self.writer_client, self.query_params,
+                         self.optimize_performance)
 
 
 class GaarfBqOperator(BaseOperator):
